@@ -5,14 +5,13 @@ use warnings;
 use 5.008_001;
 
 use Getopt::Long qw(:config posix_default no_ignore_case no_ignore_case_always);
-use IO::Socket::INET;
 use List::Util qw(first);
 
 use App::Memcached::Tool;
 use App::Memcached::Tool::DataSource;
 use App::Memcached::Tool::Util ':all';
 
-use version; our $VERSION = 'v0.9.1';
+use version; our $VERSION = 'v0.9.2';
 
 my @MODES        = qw(display dump stats settings sizes help man);
 my $DEFAULT_MODE = $MODES[0];
@@ -73,7 +72,9 @@ sub run {
     my $self = shift;
     debug "[start] $self->{mode} $self->{addr}";
     my $method = $self->{mode};
-    unless ($self->$method) {
+    my $ret    = $self->$method;
+    $self->{ds}->disconnect;
+    unless ($ret) {
         warn "Command '$self->{mode}' seems failed. Set '--debug' option if you want to see debug logs.";
         exit 1;
     }
@@ -84,7 +85,7 @@ sub display {
     my $self = shift;
 
     my %stats;
-    my $max;
+    my $max = 1;
 
     my $resp_items = $self->{ds}->query('stats items');
     for my $line (@$resp_items) {
